==> elgg-1.11.0.zip: elgg-1.11.0/mod/thewire/languages/es.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'thewire' => "The Wire",
	'thewire:everyone' => "Todos los post",
	'thewire:user' => "los posts de %s",
	'thewire:friends' => "Los post de tus amigos",
	'thewire:replying' => "Responder a %s (@%s) quien escribi&oacute;",
	'thewire:thread' => "Hilo",
	'thewire:charleft' => "caracteres restantes",
	'thewire:tags' => "Posts etiquetados con '%s'",
	'thewire:noposts' => "No hay posts",
	'item:object:thewire' => "Posts",
	'thewire:by' => 'Post publicado por %s',
	'thewire:previous:help' => "Ver posts anteriores",
	'thewire:hide:help' => "Ocultar posts anteriores",

	/**
	 * The wire river
	 */
	'river:create:object:thewire' => "%s ha posteado en %s",
	'thewire:wire' => 'wire',

	/**
	 * Wire widget
	 */
	'thewire:widget:desc' => 'Mostrar tus últimos post de The Wire',
	'thewire:num' => 'N&uacute;mero de posts a mostrar',
	'thewire:moreposts' => 'M&aacute;s posts',

	/**
	 * Status messages
	 */
	'thewire:posted' => "Tu mensaje ha sido publicado exitosamente a The Wire.",
	'thewire:deleted' => "El post ha sido borrado exitosamente.",
	'thewire:blank' => "Necesitas ingresar más texto para publicar.",
	'thewire:notfound' => "No se pudo encontrar el post.",
	'thewire:notsaved' => "Lo sentimos. No pudimos guardar este post",
	'thewire:notdeleted' => "No se pudo borrar este post.",

	/**
	 * Notifications
	 */
	'thewire:notify:summary' => 'Nuevo post: %s',
	'thewire:notify:subject' => "Nueva entrada en el hilo de %s",
	'thewire:notify:reply' => '%s ha respondido a %s en the wire:',
	'thewire:notify:post' => '%s ha posteado en the wire:',
	'thewire:notify:footer' => "Ver y responder:\n%s",

	/**
	 * Settings
	 */
	'thewire:settings:limit' => "Maximum number of characters for wire messages:",
	'thewire:settings:limit:none' => "No limit",
);

==> elgg-3.3.20.zip: elgg-3.3.20/mod/thewire/languages/es.php <==
<?php
/**
 * Translation file
 *
 * Note: don't change the return array to short notation because Transifex can't handle those during `tx push -s`
 */

return array(

	/**
	 * Menu items and titles
	 */
	'thewire' => "The Wire",

	'item:object:thewire' => "Posts",
	'collection:object:thewire' => 'Wire posts',
	'collection:object:thewire:all' => "Todos los post",
	'collection:object:thewire:owner' => "los posts de %s",
	'collection:object:thewire:friends' => "Los post de tus amigos",

	'thewire:replying' => "Responder a %s (@%s) quien escribi&oacute;",
	'thewire:thread' => "Hilo",
	'thewire:charleft' => "caracteres restantes",
	'thewire:tags' => "Posts etiquetados con '%s'",
	'thewire:noposts' => "No hay posts",

	'thewire:by' => 'Post publicado por %s',
	'thewire:previous:help' => "Ver posts anteriores",
	'thewire:hide:help' => "Ocultar posts anteriores",

	'thewire:form:body:placeholder' => "What's happening?",
	
	/**
	 * The wire river
	 */
	'river:object:thewire:create' => "%s posted to %s",
	'thewire:wire' => 'wire',

	/**
	 * Wire widget
	 */
	
	'widgets:thewire:description' => 'Mostrar tus últimos post de The Wire',
	'thewire:num' => 'N&uacute;mero de posts a mostrar',
	'thewire:moreposts' => 'M&aacute;s posts',

	/**
	 * Status messages
	 */
	'thewire:posted' => "Tu mensaje ha sido publicado exitosamente a The Wire.",
	'thewire:deleted' => "El post ha sido borrado exitosamente.",
	'thewire:blank' => "Necesitas ingresar más texto para publicar.",
	'thewire:notsaved' => "Lo sentimos. No pudimos guardar este post",
	'thewire:notdeleted' => "No se pudo borrar este post.",

	/**
	 * Notifications
	 */
	'thewire:notify:summary' => 'Nuevo post: %s',
	'thewire:notify:subject' => "Nueva entrada en el hilo de %s",
	'thewire:notify:reply' => '%s ha respondido a %s en the wire:',
	'thewire:notify:post' => '%s ha posteado en the wire:',
	'thewire:notify:footer' => "Ver y responder:\n%s",

	/**
	 * Settings
	 */
	'thewire:settings:limit' => "Maximum number of characters for wire messages:",
	'thewire:settings:limit:none' => "No limit",
);
